@@ -14,6 +14,9 @@ from utils.poseMeasure import PoseMeasure
 from utils.normarlize import getPoseEmbeddingList, getPoseSize
 from utils.pose_util import Coordinate
 from tqdm import tqdm
+from distutils.dep_util import newer
+import os
+from PyQt6 import uic
 
 def get_dance_audio_list():
     audio_list_path = DANCE_AUDIO_PATH
@@ -34,7 +37,7 @@ def dumps_json_data(json_path, data):
     with open(json_path, 'w', encoding='UTF-8-sig') as f:
         f.write(json.dumps(data, ensure_ascii=False, indent = 4, sort_keys = True))
 
-def get_json_data_all(json_path):
+def get_json_data_all(json_path) -> dict:
     with open(json_path, 'r') as f:
         data =  json.load(f)
     return data
@@ -45,8 +48,8 @@ def get_json_data(json_path, audio_name):
     return data[audio_name]
 
 def write_json_data(json_path, data):
-    with open(json_path, 'w') as f:
-        json.dump(data, f, indent=4)
+    with open(json_path, 'w', encoding="utf-8") as f:
+        json.dump(data, f, indent=4, ensure_ascii=False)
 
 def get_audio_name(audio_path):
     return audio_path.split("/")[-1].split(".")[0].split("_")[0]
@@ -272,23 +275,21 @@ def get_embedding_for_tflite_with_label(poses, embedding, labels, side, joint, c
             pass
     return pose_data, embedding_data, label_data
 
-def get_embedding_for_tflite_with_label_taekwondo(poses, embeddingType, labels, dimension="3d"):
+def get_embedding_for_tflite_with_label_taekwondo(poses, embeddingType, dimension="3d"):
     embedding_data = []
     pose_data = []
-    label_data = []
     valid_idx = []
     if embeddingType != "TAEKWONDO":
-        for idx, (label, pose) in enumerate(zip(labels, poses)):
+        for idx, pose in enumerate(poses):
             try:
                 embedding_data.append(getPoseEmbeddingList(pose, embeddingType.upper(), dimension))
                 pose_data.append(pose)
-                label_data.append(label)
                 valid_idx.append(idx)
             except Exception as e:
                 print(e)
                 pass
     else:
-        for idx, (label, pose) in enumerate(zip(labels[:-4], poses[:-4])):
+        for idx, pose in enumerate(poses[:-4]):
             try:
                 poseSize = 100 / getPoseSize(pose)
                 post_pose = poses[idx+3]
@@ -300,11 +301,10 @@ def get_embedding_for_tflite_with_label_taekwondo(poses, embeddingType, labels,
                         vector.append((i.z-j.z) * poseSize)
                 embedding_data.append(vector)
                 pose_data.append(pose)
-                label_data.append(label)
                 valid_idx.append(idx)
             except Exception as e:
                 pass
-    return pose_data, embedding_data, label_data, valid_idx
+    return pose_data, embedding_data, valid_idx
 
 def get_embedding_for_tflite(poses, embedding, side, joint, coord, equation):
     embedding_data = []
@@ -327,6 +327,7 @@ def get_embedding_for_tflite(poses, embedding, side, joint, coord, equation):
                 embedding_data.append(getPoseEmbeddingList(pose, embedding.upper()))
             pose_data.append(pose)
         except Exception as e:
+            print(e)
             pass
     return pose_data, embedding_data
 
@@ -414,4 +415,80 @@ def get_string_model_summary(model):
     stringlist = []
     model.summary(print_fn=lambda x: stringlist.append(x))
     short_model_summary = "\n".join(stringlist)
-    return short_model_summary
\ No newline at end of file
+    return short_model_summary
+
+def getHipCenter(pose):
+    pose_measure = PoseMeasure(pose)
+    return pose_measure.getHipCenterPoint().x
+
+def getPoseHeight(pose, dimension=XYZ):
+    pose_measure = PoseMeasure(pose)
+    nose_shoulder = pose_measure.getNoseShoulderCenterDistance(dimension)
+    shoulder_hip = pose_measure.getShoulderCenterHipCenterDistance(dimension)
+    hip_knee = pose_measure.getHipKneeMinusDistance(dimension)
+    knee_ankle = pose_measure.getKneeAnkleMinusDistance(dimension)
+    return nose_shoulder + shoulder_hip + hip_knee + knee_ankle
+
+def get_embedding_for_tflite_taekwondo_live(poses, embeddingType, dimension="3d"):
+    embedding_data = []
+    for pose in poses:
+        try:
+            embedding_data.append(getPoseEmbeddingList(pose, embeddingType.upper(), dimension))
+        except Exception as e:
+            print(e)
+            pass
+    return embedding_data
+
+def get_embedding_for_tflite_taekwondo_single(pose, embeddingType, dimension):
+    try:
+        return getPoseEmbeddingList(pose, embeddingType.upper(), dimension)
+    except Exception as e:
+        return None
+
+def getFootHeelPosition(pose, dimension=Y):
+    pose_measure = PoseMeasure(pose)
+    foot = pose_measure.getFootindexPorint(dimension, AVG)
+    heel = pose_measure.getHeelPorint(dimension, AVG)
+    return (foot + heel)/2
+
+def getAnklePosition(pose,  dimension=Y):
+    pose_measure = PoseMeasure(pose)
+    ankle = pose_measure.getAnklePoint(dimension, AVG)
+    return ankle
+
+def check_option_json_file(path):
+    if os.path.isfile(path):
+        return get_json_data_all(path)
+    else:
+        last_path = path.split('/')[-1]
+        defalut_path = f'./data/defalut/{last_path}'
+        data = get_json_data_all(defalut_path)
+        dump_json_data(path, data)
+        return data
+
+def ui_auto_complete(ui_file, ui_to_py_file):
+    encoding = 'utf-8'
+    # UI 파일이 존재하지 않으면 아무 작업도 수행하지 않는다.
+    if not os.path.isfile(ui_file):
+        return
+    # UI 파일이 업데이트 됬는지 확인하고, 업데이트 되었으면 *.py로 변환한다
+    if newer(ui_file, ui_to_py_file):
+        print(f"{ui_file.split('/')[-1]} has changed")
+        # ui 파일이 업데이트 되었다, py파일을 연다.
+        fp = open(ui_to_py_file, "w", encoding=encoding)
+        # ui 파일을 py파일로 컴파일한다.
+        uic.compileUi(ui_file, fp, execute=True, indent=4)
+        fp.close()
+    else:
+        print(f"{ui_file.split('/')[-1]} has not changed")
+
+def remove_trash_pose(poses):
+    newPoses = []
+    for pose in poses:
+        try:
+            inputs = getPoseEmbeddingList(pose, "UPPER")
+            newPoses.append(pose)
+        except:
+            continue
+    return newPoses
+        
