@@ -1,18 +1,51 @@
 import os
 
+MATCOLORS = {
+    'black':                '#000000',
+    'antiquewhite':         '#FAEBD7',
+    'aqua':                 '#00FFFF',
+    'aquamarine':           '#7FFFD4',
+    'azure':                '#F0FFFF',
+    'beige':                '#F5F5DC',
+    'bisque':               '#FFE4C4',
+    'aliceblue':            '#F0F8FF',
+    'blanchedalmond':       '#FFEBCD',
+    'blue':                 '#0000FF',
+    'blueviolet':           '#8A2BE2',
+    'brown':                '#A52A2A',
+    'burlywood':            '#DEB887',
+    'cadetblue':            '#5F9EA0',
+    'chartreuse':           '#7FFF00',
+    'chocolate':            '#D2691E',
+    'coral':                '#FF7F50',
+    'cornflowerblue':       '#6495ED',
+    'cornsilk':             '#FFF8DC',
+    'crimson':              '#DC143C',
+    'cyan':                 '#00FFFF',
+    'darkblue':             '#00008B',
+    'darkcyan':             '#008B8B',
+    'darkgoldenrod':        '#B8860B',
+    'darkgray':             '#A9A9A9',
+    'darkgreen':            '#006400',
+    'darkgrey':             '#A9A9A9',
+    'darkkhaki':            '#BDB76B',
+    'darkmagenta':          '#8B008B',
+    'darkolivegreen':       '#556B2F',
+    'darkorange':           '#FF8C00',
+    'darkorchid':           '#9932CC',
+    'darkred':              '#8B0000',
+    'darksalmon':           '#E9967A',
+    'darkseagreen':         '#8FBC8F',
+    'darkslateblue':        '#483D8B',
+    'darkslategray':        '#2F4F4F',
+    'darkslategrey':        '#2F4F4F',
+    'darkturquoise':        '#00CED1',}
 
+MATCOLORNAMES = list(MATCOLORS.keys())
 #------------------------------------------------------------------------
 # Path 
 DIR_PATH = os.getcwd()
-if DIR_PATH.split('/')[-1] == "poseAnalizer":
-    KNN_PATH = DIR_PATH + '/GymMate/data/knnData'
-    KT_LOGIC_COACHING_PATH = DIR_PATH + "/GymMate/ktLogicCoaching"
-    GYMMATE_FONT_PATH = DIR_PATH + "/GymMate/font"
-elif DIR_PATH.split('/')[-1] == "GymMate":
-    KNN_PATH = DIR_PATH + '/data/knnData'
-    KT_LOGIC_COACHING_PATH = DIR_PATH + "/ktLogicCoaching"
-    GYMMATE_FONT_PATH = DIR_PATH + "/font"
-
+KNN_PATH = DIR_PATH + '/data/knnData'
 DANCE_DATA_PATH = DIR_PATH + '/data/danceData'
 
 DANCE_VIDEO_PATH = DANCE_DATA_PATH + '/video'
@@ -22,7 +55,7 @@ DANCE_AUDIO_PATH = DANCE_DATA_PATH + '/audio'
 DANCE_AUDIO_COMMON_PATH = DANCE_AUDIO_PATH + '/common/'
 
 
-AUDIO_JSON_PATH = DANCE_DATA_PATH + "/audio_info.json"
+AUDIO_JSON_PATH = DIR_PATH + "/audio_info.json"
 NAS_PATH = "/Volumes/Multimedia/댄스"
 MLP_PATH_DATA = "/Volumes/FrameData/mlp/data"
 MLP_PATH = "/Volumes/FrameData/mlp"
@@ -34,12 +67,38 @@ LINUX_LSTM_PATH = "/home/hnh/FrameData/lstm"
 TAEKWONDO_PATH = "/Volumes/FrameData/TaeKwondo"
 TAEKWONDO_LINUX_PATH = "/home/hnh/FrameData/TaeKwondo"
 
+YOLO_PATH = "/Volumes/FrameData/yolo"
+
 POSE_MEASURE_SAVE_PATH = DIR_PATH + "/poseutil/utils/poseMeasure.py"
 
+KT_LOGIC_COACHING_PATH = DIR_PATH + "/ktLogicCoaching"
+GYMMATE_FONT_PATH = DIR_PATH + "/font"
+
 NO_COUNTING_PATH = "/Volumes/FrameData/no_counting_data"
 APP_LIST = ["pose-test-app", "gymmate-app"]
 
-MAPPING_MAP = {
+MLP_LINK = {
+    "Weight/DumbbellBenchPress": ["Weight/BarbellBenchPress"],
+    "Weight/DumbbellPullover" : ["Weight/BarbellPullover"],
+    "Weight/BentOverLateralRaise" : ["Beginner/BandBentOverLateralRaise", "Beginner/WaterBottleBentOverLateralRaise"],
+    "Weight/BentOverDumbbellRow" : ["Beginner/BentOverWaterBottleRow"],
+    "Weight/DumbbellConcentrationCurl" : ["Beginner/BandConcentrationCurl", "Beginner/WaterBottleConcentrationCurl"],
+    "Weight/DumbbellShoulderPress" : ["Beginner/WaterBottleShoulderPress"],
+    "Weight/DumbbellSideBend" : ["Beginner/WaterBottleSideBend"],
+    "Weight/FrontLateralRaise" : ["Beginner/BandFrontLateralRaise", "Beginner/WaterBottleFrontLateralRaise", "Senior/Senior22"],
+    "Weight/OneArmDumbbellTricepsKickback" : ["Beginner/OneArmWaterBottleTricepsKickback"],
+    "Weight/OneArmOverheadDumbbellTricepsExtension" : ["Beginner/OneArmOverheadWaterBottleTricepsExtension"],
+    "Weight/OneDumbbellFrontRaise" : ["Beginner/BandFrontRaise", "Beginner/WaterBottleFrontRaise"],
+    "Weight/ReverseWristCurl" : ["Beginner/WaterBottleReverseWristCurl"],
+    "Weight/SideLateralRaise" : ["Beginner/BandSideLateralRaise", "Beginner/WaterBottleSideLateralRaise", "Senior/Senior21"],
+    "Weight/StandingAlternateDumbbellCurl" : ["Beginner/StandingAlternateBandCurl", "Beginner/StandingAlternateWaterBottleCurl"],
+    "Weight/StandingHammerCurl" : ["Beginner/StandingBandHammerCurl", "Beginner/StandingWaterBottleHammerCurl"],
+    "Weight/StandingBarbellCurl" : ["Senior/Senior23", "Senior/Senior24"],
+    "Weight/Squat" : ["Senior/Senior25"],
+    "Weight/GoodMorningDeadlift" : ["Senior/Senior26"]
+}
+
+LSTM_LINK = {
     "Weight/DumbbellBenchPress": ["Weight/BarbellBenchPress"],
     "Weight/DumbbellPullover" : ["Weight/BarbellPullover"],
     "Weight/BentOverLateralRaise" : ["Beginner/BandBentOverLateralRaise", "Beginner/WaterBottleBentOverLateralRaise"],
@@ -56,6 +115,7 @@ MAPPING_MAP = {
     "Weight/StandingAlternateDumbbellCurl" : ["Beginner/StandingAlternateBandCurl", "Beginner/StandingAlternateWaterBottleCurl"],
     "Weight/StandingHammerCurl" : ["Beginner/StandingBandHammerCurl", "Beginner/StandingWaterBottleHammerCurl"]
 }
+
 #------------------------------------------------------------------------
 # list view Setup
 EMBEDDINGLIST = ["UPPER", "BODYNOSE", "LOWER","FULL", "HAND", "LOWERYANG", "TAEKWONDO"]
@@ -350,7 +410,7 @@ HAND = "HAND"
 HANDLEFT = "HANDLEFT"
 HANDRIGHT = "HANDRIGHT"
 BODYNOSE = "BODYNOSE"
-BODYNOSELEFT = "BDOYNOSELEFT"
+BODYNOSELEFT = "BODYNOSELEFT"
 BODYNOSERIGHT = "BODYNOSERIGHT"
 LOWERYANG = "LOWERYANG"
 LOWERYANGLEFT = "LOWERYANGLEFT"
@@ -485,21 +545,27 @@ DANCE_BODY_RESULT = ["LEFT_ANKLE","LEFT_KNEE","LEFT_HIP","LEFT_SHOULDER", "LEFT_
 BODY_SET = [LEFT_SHOULDER, RIGHT_SHOULDER,LEFT_HIP, RIGHT_HIP]
 
 BODY_DOT = [
-    0, 11, 12, 13, 14, 15, 16, 23, 24, 25, 26, 27, 28,
+    0, 11, 12, 13, 14, 15, 16, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32
+]
+FACE_DOT = [
+    LEFT_EAR, LEFT_EYE, NOSE, RIGHT_EYE, RIGHT_EAR
 ]
 HAND_DOT = [
     0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20
 ]
 LEFT_LINK = [
-    [12, 14], [14, 16], [12, 24], [24, 26], [26, 28], 
+    [12, 14], [14, 16], [12, 24], [24, 26], [26, 28], [28, 30], [28, 32], [30, 32]
 ]
 RIGHT_LINK = [
-    [11, 13], [13, 15], [11, 23], [23, 25], [25, 27],
+    [11, 13], [13, 15], [11, 23], [23, 25], [25, 27], [27, 29], [27, 31], [29, 31]
 ]
 CENTER_LINK = [
     [11, 12], [23, 24]
 ]
-HAND = [
+FACE_LINK = [
+    [LEFT_EAR, LEFT_EYE], [LEFT_EYE, NOSE], [NOSE, RIGHT_EYE], [RIGHT_EYE, RIGHT_EAR]
+]
+HAND_LINK = [
     [0, 1], [1, 2], [2, 3], [3, 4], 
     [0, 5], [5, 6], [6, 7], [7, 8],
     [9, 10], [10, 11], [11, 12],
@@ -508,6 +574,8 @@ HAND = [
     [5, 9], [9, 13], [13, 17]
 ]
 
+
+
 KEY_INFO_CAPTURE_LIVE_HEADER = [""]
 KEY_INFO_CAPTURE_LIVE_HEADER = [""]
 STATIC_HEADER = ["Width", "Height", "Origin", "Compare"]
@@ -575,22 +643,187 @@ TAEKWONDO_LABEL = [
             "NONE"
             ]
 
+NEW_TAEKWONDO_LABWL_MAP = {
+    "STANDBY" : 0 ,
+    "LEFT_MIDDLE_SIDE_KICK" : 1 ,
+    "LEFT_UPPER_SIDE_KICK" : 2 ,
+    "RIGHT_MIDDLE_SIDE_KICK" : 3 ,
+    "RIGHT_UPPER_SIDE_KICK" : 4 ,
+    "LEFT_MIDDLE_FRONT_KICK" : 5 ,
+    "LEFT_UPPER_FRONT_KICK" : 6 ,
+    "RIGHT_MIDDLE_FRONT_KICK" : 7 ,
+    "RIGHT_UPPER_FRONT_KICK" : 8 ,
+    "LEFT_DOWNWARD_KICK" : 9 ,
+    "RIGHT_DOWNWARD_KICK" : 10,
+    "LEFT_MIDDLE_ROUND_KICK" : 11,
+    "LEFT_UPPER_ROUND_KICK" : 12,
+    "RIGHT_MIDDLE_ROUND_KICK" : 13,
+    "RIGHT_UPPER_ROUND_KICK" : 14,
+    "LEFT_MIDDLE_BACK_KICK" : 15,
+    "LEFT_UPPER_BACK_KICK" : 16,
+    "RIGHT_MIDDLE_BACK_KICK" : 17,
+    "RIGHT_UPPER_BACK_KICK" : 18,
+    "LEFT_MIDDLE_BACK_ROUND_KICK" : 19,
+    "LEFT_UPPER_BACK_ROUND_KICK" : 20,
+    "RIGHT_MIDDLE_BACK_ROUND_KICK" : 21,
+    "RIGHT_UPPER_BACK_ROUND_KICK" : 22,
+    "LEFT_MIDDLE_TURN_ROUND_KICK" : 23,
+    "LEFT_UPPER_TURN_ROUND_KICK" : 24,
+    "RIGHT_MIDDLE_TURN_ROUND_KICK" : 25,
+    "RIGHT_UPPER_TURN_ROUND_KICK" : 26,
+    "LEFT_PUNCH" : 27,
+    "RIGHT_PUNCH" : 28,
+}
+
+NEW_TAEKWONDO_LABEL = [
+    "STANDBY",
+    "LEFT_MIDDLE_SIDE_KICK", 
+    "LEFT_UPPER_SIDE_KICK", 
+    "RIGHT_MIDDLE_SIDE_KICK", 
+    "RIGHT_UPPER_SIDE_KICK", 
+    "LEFT_MIDDLE_FRONT_KICK",
+    "LEFT_UPPER_FRONT_KICK",
+    "RIGHT_MIDDLE_FRONT_KICK",
+    "RIGHT_UPPER_FRONT_KICK",
+    "LEFT_DOWNWARD_KICK",
+     "RIGHT_DOWNWARD_KICK",
+     "LEFT_MIDDLE_ROUND_KICK",
+     "LEFT_UPPER_ROUND_KICK",
+     "RIGHT_MIDDLE_ROUND_KICK",
+     "RIGHT_UPPER_ROUND_KICK",
+     "LEFT_MIDDLE_BACK_KICK",
+     "LEFT_UPPER_BACK_KICK",
+     "RIGHT_MIDDLE_BACK_KICK",
+     "RIGHT_UPPER_BACK_KICK",
+     "LEFT_MIDDLE_BACK_ROUND_KICK",
+     "LEFT_UPPER_BACK_ROUND_KICK",
+     "RIGHT_MIDDLE_BACK_ROUND_KICK",
+     "RIGHT_UPPER_BACK_ROUND_KICK",
+     "LEFT_MIDDLE_TURN_ROUND_KICK",
+     "LEFT_UPPER_TURN_ROUND_KICK",
+     "RIGHT_MIDDLE_TURN_ROUND_KICK",
+     "RIGHT_UPPER_TURN_ROUND_KICK",
+     "LEFT_PUNCH",
+     "RIGHT_PUNCH",
+]
+
+NEW_TAEKWONDO_LABEL_MAP_REVERSE = {
+    0 : "STANDBY",
+    1 : "LEFT_MIDDLE_SIDE_KICK", 
+    2 : "LEFT_UPPER_SIDE_KICK", 
+    3 : "RIGHT_MIDDLE_SIDE_KICK", 
+    4 : "RIGHT_UPPER_SIDE_KICK", 
+    5 : "LEFT_MIDDLE_FRONT_KICK",
+    6 : "LEFT_UPPER_FRONT_KICK",
+    7 : "RIGHT_MIDDLE_FRONT_KICK",
+    8 : "RIGHT_UPPER_FRONT_KICK",
+    9 : "LEFT_DOWNWARD_KICK",
+    10 : "RIGHT_DOWNWARD_KICK",
+    11 : "LEFT_MIDDLE_ROUND_KICK",
+    12 : "LEFT_UPPER_ROUND_KICK",
+    13 : "RIGHT_MIDDLE_ROUND_KICK",
+    14 : "RIGHT_UPPER_ROUND_KICK",
+    15 : "LEFT_MIDDLE_BACK_KICK",
+    16 : "LEFT_UPPER_BACK_KICK",
+    17 : "RIGHT_MIDDLE_BACK_KICK",
+    18 : "RIGHT_UPPER_BACK_KICK",
+    19 : "LEFT_MIDDLE_BACK_ROUND_KICK",
+    20 : "LEFT_UPPER_BACK_ROUND_KICK",
+    21 : "RIGHT_MIDDLE_BACK_ROUND_KICK",
+    22 : "RIGHT_UPPER_BACK_ROUND_KICK",
+    23 : "LEFT_MIDDLE_TURN_ROUND_KICK",
+    24 : "LEFT_UPPER_TURN_ROUND_KICK",
+    25 : "RIGHT_MIDDLE_TURN_ROUND_KICK",
+    26 : "RIGHT_UPPER_TURN_ROUND_KICK",
+    27 : "LEFT_PUNCH",
+    28 : "RIGHT_PUNCH",
+}
+
+NEW_TAEKWONDO_LABEL_MAP_REVERSE_KR = {
+    0 : "준비",
+    1 : "왼발 중단 옆차기", 
+    2 : "왼발 상단 옆차기", 
+    3 : "오른발 중단 옆차기", 
+    4 : "오른발 상단 옆차기", 
+    5 : "왼발 중단 앞차기",
+    6 : "왼발 상단 앞차기",
+    7 : "오른발 중단 앞차기",
+    8 : "오른발 상단 앞차기",
+    9 : "왼발 내려차기",
+    10 : "오른발 내려차기",
+    11 : "왼발 중단 돌려차기",
+    12 : "왼발 상단 돌려차기",
+    13 : "오른발 중단 돌려차기",
+    14 : "오른발 상단 돌려차기",
+    15 : "왼발 중단 뒤차기",
+    16 : "왼발 상단 뒤차기",
+    17 : "오른발 중단 뒤차기",
+    18 : "오른발 상단 뒤차기",
+    19 : "왼발 중단 뒤후리기",
+    20 : "왼발 상단 뒤후리기",
+    21 : "오른발 중단 뒤후리기",
+    22 : "오른발 상단 뒤후리기",
+    23 : "왼발 중단 돌개차기",
+    24 : "왼발 상단 돌개차기",
+    25 : "오른발 중단 돌개차기",
+    26 : "오른발 상단 돌개차기",
+    27 : "왼손 정권",
+    28 : "오른손 정권",
+}
+
+NEW_TAEKWONDO_LABEL_MAP_KR = {
+    "준비" : 0,
+    "왼발 중단 옆차기" : 1,
+    "왼발 상단 옆차기" : 2,
+    "오른발 중단 옆차기" : 3,
+    "오른발 상단 옆차기" : 4,
+    "왼발 중단 앞차기" : 5,
+    "왼발 상단 앞차기" : 6,
+    "오른발 중단 앞차기" : 7,
+    "오른발 상단 앞차기" : 8,
+    "왼발 내려차기" : 9,
+    "오른발 내려차기" : 10,
+    "왼발 중단 돌려차기" : 11,
+    "왼발 상단 돌려차기" : 12,
+    "오른발 중단 돌려차기" : 13,
+    "오른발 상단 돌려차기" : 14,
+    "왼발 중단 뒤차기" : 15,
+    "왼발 상단 뒤차기" : 16,
+    "오른발 중단 뒤차기" : 17,
+    "오른발 상단 뒤차기" : 18,
+    "왼발 중단 뒤후리기" : 19,
+    "왼발 상단 뒤후리기" : 20,
+    "오른발 중단 뒤후리기" : 21,
+    "오른발 상단 뒤후리기" : 22,
+    "왼발 중단 돌개차기" : 23,
+    "왼발 상단 돌개차기" : 24,
+    "오른발 중단 돌개차기" : 25,
+    "오른발 상단 돌개차기" : 26,
+    "왼손 정권" : 27,
+    "오른손 정권" : 28,
+}
+
 MODEL_TRANSFORMER = 'transformer'
 MODEL_LSTM = 'lstm'
 
 MP2YOLO = {
-    RIGHT_SHOULDER: 6,
-    RIGHT_ELBOW: 8,
-    RIGHT_WRIST: 10,
+    NOSE: 0,
+    LEFT_EYE: 1,
+    RIGHT_EYE: 2,
+    LEFT_EAR: 3,
+    RIGHT_EAR: 4,
     LEFT_SHOULDER: 5,
+    RIGHT_SHOULDER: 6,
     LEFT_ELBOW: 7,
+    RIGHT_ELBOW: 8,
     LEFT_WRIST: 9,
-    RIGHT_HIP: 12,
-    RIGHT_KNEE: 14,
-    RIGHT_ANKLE: 16,
+    RIGHT_WRIST: 10,
     LEFT_HIP: 11,
+    RIGHT_HIP: 12,
     LEFT_KNEE: 13,
-    LEFT_ANKLE: 15
+    RIGHT_KNEE: 14,
+    LEFT_ANKLE: 15,
+    RIGHT_ANKLE: 16,    
 }
 
 TAEKWONDO_LSTM_MAP_REVERSE_KR = {
@@ -602,4 +835,20 @@ TAEKWONDO_LSTM_MAP_REVERSE_KR = {
     5 : "뒤차기" ,
     6 : "뒤후리기" ,
     7 : "돌개차기" ,
+}
+
+LABELING_BODY = {
+    "nose": NOSE,
+    "left_shoulder": LEFT_SHOULDER,
+    "right_shoulder": RIGHT_SHOULDER,
+    "left_elbow": LEFT_ELBOW,
+    "right_elbow": RIGHT_ELBOW,
+    "left_wrist": LEFT_WRIST,
+    "right_wrist": RIGHT_WRIST,
+    "left_hip": LEFT_HIP,
+    "right_hip": RIGHT_HIP,
+    "left_knee": LEFT_KNEE,
+    "right_knee": RIGHT_KNEE,
+    "left_ankle": LEFT_ANKLE,
+    "right_ankle": RIGHT_ANKLE,
 }
\ No newline at end of file
