@@ -383,4 +383,39 @@ def getEmbedding(lm, exerciseType):
             subtract(lm[RIGHT_ANKLE], lm[RIGHT_FOOT_INDEX]),
             subtract(lm[RIGHT_ANKLE], lm[RIGHT_HEEL]),
             subtract(lm[RIGHT_FOOT_INDEX], lm[RIGHT_HEEL])]
+         
+    elif exerciseType == 'squat':
+        embedding = [
+            subtract(lm[LEFT_KNEE], lm[LEFT_ANKLE]), 
+            subtract(lm[RIGHT_KNEE], lm[RIGHT_ANKLE]),
+            subtract(lm[LEFT_KNEE], lm[LEFT_FOOT_INDEX]), 
+            subtract(lm[RIGHT_KNEE], lm[RIGHT_FOOT_INDEX]),
+            subtract(lm[LEFT_KNEE], lm[LEFT_HEEL]), 
+            subtract(lm[RIGHT_KNEE], lm[RIGHT_HEEL]),
+            subtract(lm[LEFT_SHOULDER], lm[LEFT_ANKLE]), 
+            subtract(lm[RIGHT_SHOULDER], lm[RIGHT_ANKLE]),
+            subtract(lm[LEFT_SHOULDER], lm[LEFT_KNEE]), 
+            subtract(lm[RIGHT_SHOULDER], lm[RIGHT_KNEE]),
+            subtract(lm[LEFT_HIP], lm[LEFT_ANKLE]), 
+            subtract(lm[RIGHT_HIP], lm[RIGHT_ANKLE]), 
+            subtract(lm[LEFT_HIP], lm[LEFT_FOOT_INDEX]), 
+            subtract(lm[RIGHT_HIP], lm[RIGHT_FOOT_INDEX]), 
+            subtract(lm[LEFT_HIP], lm[LEFT_HEEL]), 
+            subtract(lm[RIGHT_HIP], lm[RIGHT_HEEL]), 
+            subtract(lm[LEFT_HIP], lm[LEFT_KNEE]), 
+            subtract(lm[RIGHT_HIP], lm[RIGHT_KNEE]),
+            subtract(lm[LEFT_KNEE], lm[RIGHT_KNEE]), 
+            subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE]),
+            subtract(subtract(lm[LEFT_KNEE], lm[RIGHT_KNEE]), 
+                     subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE])),
+            subtract(subtract(lm[LEFT_HIP], lm[RIGHT_HIP]), 
+                     subtract(lm[LEFT_ANKLE], lm[RIGHT_ANKLE])),
+            subtract(lm[LEFT_KNEE], lm[RIGHT_HIP]),
+            subtract(lm[RIGHT_KNEE], lm[LEFT_HIP]),
+            subtract(lm[LEFT_KNEE], lm[RIGHT_ANKLE]),
+            subtract(lm[RIGHT_KNEE], lm[LEFT_ANKLE]),
+            subtract(lm[LEFT_KNEE], lm[RIGHT_SHOULDER]),
+            subtract(lm[RIGHT_KNEE], lm[LEFT_SHOULDER])
+            ]
+         
     return embedding
