@@ -41,6 +41,19 @@ class PoseMeasure:
         self.leftFootIndex = pose[LEFT_FOOT_INDEX]
         self.rightFootIndex = pose[RIGHT_FOOT_INDEX]
 
+    def getAngleFromString(self, angleSelect: str):
+        if "/" not in angleSelect:
+            func, *inputs = angleSelect.split(",")
+            angle = round(getattr(self, func)(*inputs), 2)
+        else:
+            numerator, denominator = angleSelect.split("/")
+            func, *inputs = numerator.split(",")
+            numeratorAngle = round(getattr(self, func)(*inputs), 2)
+            func, *inputs = denominator.split(",")
+            denominatorAngle = round(getattr(self, func)(*inputs), 2)
+            angle = numeratorAngle / denominatorAngle
+        return angle
+
     def getCoord(self, a, dimension):
         if dimension == X:
             return a.x
@@ -319,7 +332,12 @@ class PoseMeasure:
             return right
         elif direction == AVG:
             return avg        
-
+        
+    def getShoulderCenterHipCenterDistance(self, dimension=XYZ):
+        shoulder_center = self.getCenterPoint(self.leftShoulder, self.rightShoulder)
+        hip_center = self.getCenterPoint(self.leftHip, self.rightHip)
+        result = self.getDistance(shoulder_center, hip_center, dimension)
+        return result
 
     def getNoseShoulderDistance(self, dimension=XYZ, direction=AVG):
         left = self.getDistance(self.leftNose, self.leftShoulder, dimension)
@@ -330,8 +348,13 @@ class PoseMeasure:
         elif direction == RIGHT:
             return right
         elif direction == AVG:
-            return avg        
-
+            return avg
+        
+    def getNoseShoulderCenterDistance(self, dimension=XYZ):
+        center = self.getCenterPoint(self.leftShoulder, self.rightShoulder)
+        result = self.getDistance(self.leftNose, center, dimension)
+        return result
+        
 
     def getNoseShoulderPlusDistance(self, dimension=XYZ, sDimension=Z, standard=LEFT_SHOULDER):
         standard = int(standard)
@@ -863,6 +886,10 @@ class PoseMeasure:
         elif direction == AVG:
             return avg        
 
+    def getHipCenterPoint(self):
+        hipCenter = self.getCenterPoint(self.leftHip, self.rightHip)
+        return hipCenter
+
 
     def getHipMinusPoint(self, dimension, sDimension=Z, standard=LEFT_SHOULDER):
         standard = int(standard)
@@ -1605,6 +1632,18 @@ class PoseMeasure:
     def getAnkleDistance(self, dimension=XYZ):
         return self.getDistance(self.leftAnkle, self.rightAnkle, dimension)        
 
+    def getAnkleFootDistance(self, dimension=XYZ, direction=AVG):
+        left_foot = self.getCenterPoint(self.leftFootIndex, self.leftHeel)
+        right_foot = self.getCenterPoint(self.rightFootIndex, self.rightHeel)
+        left = self.getDistance(left_foot, self.leftAnkle, dimension)
+        right = self.getDistance(right_foot, self.rightAnkle, dimension)
+        avg = (left + right) / 2
+        if direction == LEFT:
+            return left
+        elif direction == RIGHT:
+            return right
+        elif direction == AVG:
+            return avg        
 
     def getAnkleKneeFootIndexAngle(self, dimension=XYZ, direction=AVG):
         left = self.getAngle(self.leftAnkle, self.leftKnee, self.leftFootIndex, dimension)
@@ -1750,7 +1789,39 @@ class PoseMeasure:
         else:
             return self.rightAnkle            
 
+    def getHeelPorint(self, dimension, direction):
+        left = self.getCoord(self.leftHeel, dimension)
+        right = self.getCoord(self.rightHeel, dimension)
+        avg = (left + right) / 2
+        if direction == LEFT:
+            return left
+        elif direction == RIGHT:
+            return right
+        elif direction == AVG:
+            return avg        
 
+    def getFootindexPoint(self, dimension, direction):
+        left = self.getCoord(self.leftFootIndex, dimension)
+        right = self.getCoord(self.rightFootIndex, dimension)
+        avg = (left + right) / 2
+        if direction == LEFT:
+            return left
+        elif direction == RIGHT:
+            return right
+        elif direction == AVG:
+            return avg        
+
+    def getFootIndexHeelDistance(self, dimension=XYZ, direction=AVG):
+        left = self.getDistance(self.leftFootIndex, self.leftHeel, dimension)
+        right = self.getDistance(self.rightFootIndex, self.rightHeel, dimension)
+        avg = (left + right) / 2
+        if direction == LEFT:
+            return left
+        elif direction == RIGHT:
+            return right
+        elif direction == AVG:
+            return avg        
+        
     def getFootIndexHeelLine(self, dimension, line, direction):
         left = self.getLine(self.leftFootIndex, self.leftHeel, dimension, line)
         right = self.getLine(self.rightFootIndex, self.rightHeel, dimension, line)
@@ -1817,4 +1888,9 @@ class PoseMeasure:
         hipDistance = self.getHipDistance(XY)
 
         return wristDistance / hipDistance
-    
\ No newline at end of file
+    
+    def getOnlyForFingerClap(self):
+        wristDistance = self.getWristDistance(XY)
+        shoulderDistance = self.getShoulderDistance(XY)
+        return wristDistance / shoulderDistance    
+    
