@@ -5,7 +5,6 @@ import mediapipe as mp
 import cv2
 from tqdm import tqdm
 
-
 class data:
     def __init__(self, poseState, successCount, failCount):
         self.poseState = poseState
@@ -92,7 +91,7 @@ holistic = mp_holistic.Holistic(min_detection_confidence=0.5, min_tracking_confi
 mp_pose = mp.solutions.pose
 pose = mp_pose.Pose(min_detection_confidence=0.5, min_tracking_confidence=0.5)
 
-def get_pose_data(img):
+def get_pose_data(img, z_weight=1):
     img.flags.writeable = False
     results = pose.process(cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
     img.flags.writeable = True
@@ -106,8 +105,9 @@ def get_pose_data(img):
     height, width, _ = img.shape
     if results.pose_landmarks:
         landmarks = results.pose_landmarks.landmark
-        pose_landmark = [Coordinate(landmark.x * width, landmark.y * height, landmark.z * (width + height) * 0.1, landmark.visibility) for landmark in landmarks]
+        pose_landmark = [Coordinate(landmark.x * width, landmark.y * height, landmark.z * (width + height) * 0.1 * z_weight, landmark.visibility) for landmark in landmarks]
     else:
+        return None
         pose_landmark = [Coordinate(0, 0, 0, 0) for _ in range(33)]
 
     return pose_landmark
@@ -210,7 +210,6 @@ def sync_pose(poses, width, height, target_width, target_height):
     for pose in poses:
         pose_data.append([Coordinate(i.x / width * target_width, i.y / height * target_height, i.z / zWeight * target_zWeight) for i in pose])
     return pose_data
-            
     
 def get_video_to_pickle_data(args):
     frame_num = 0
@@ -254,4 +253,13 @@ def get_video_to_pickle_data(args):
             "height": height,
             "pose": pose_list
         }
-    return pickle_data
\ No newline at end of file
+    return pickle_data
+
+def apply_z_weight(poses, z_weight):
+    result_poses = []
+    for pose in poses:
+        result_pose = []
+        for body in pose:
+            result_pose.append(Coordinate(body.x, body.y, body.z*z_weight, body.visibility))
+        result_poses.append(result_pose)
+    return result_poses
\ No newline at end of file
